@@ -24,6 +24,7 @@ import logging
 import traceback
 logger = logging.getLogger("pyhectiqlab")
 import shutil
+from slugify import slugify
 
 class Run():
     
@@ -114,6 +115,7 @@ class Run():
         self.metrics_manager = MetricsManager(push_method=self._push_metrics)
         self.logs_buffer = Buffer(push_method=self._push_logs)
         self.add_log_stream("pyhectiqlab", level=logging.INFO)
+        self.tmp_artifacts = None
 
     def user_is_not_logged(self):
         print("User not authentificated. Use `hectiqlab add-profile` in command line.")
@@ -124,7 +126,43 @@ class Run():
         self.run_view = {}
         self.events_manager = EventsManager(True)
         self.metrics_manager = None
-        self.logs_buffer = None
+        self.logs_buffer = Buffer(push_method=self._push_logs)
+
+    @write_method
+    @action_method
+    def add_figure(self, fig: "matplotlib.figure.Figure", 
+                        name: str, 
+                        step: int = None, 
+                        tmp_path: str = None, 
+                        dpi: int = 300, 
+                        extension: str = None,
+                        wait_response: bool = False,
+                        **kwargs):
+        """Save a matplotlib figure on a temp dir and push the image to the lab.
+
+        fig [matplotlib.figure.Figure] : The matplotlib figure
+        name [str]: Use this to store the name of the artifact. 
+        step [int]: The optional step stamp of the artifacts.
+        tmp_path [str]: Use this to specify where the image has to be saved. Otherwise, a tempfile will be used.
+        dpi [int]: The resolution in dots per inch. 
+        extension [str]: The file format, e.g. 'png', 'pdf', 'svg', .... If unset, it will be infered from name or default is png.
+        wait_response [bool]: Set to true to upload sync. If False, the upload is made in background.
+        **kwargs: Extra arguments passed to `fig.savefig(..., **kwargs)`
+        """
+        if self.tmp_artifacts is None:
+            self.tmp_artifacts = tempfile.mkdtemp()
+
+        basename, name_ext = os.path.splitext(name)
+        if name_ext:
+            extension = name_ext.strip(".")
+        else:
+            extension = (extension or "png").strip(".")
+
+        slug_name = slugify(basename) 
+        fname = os.path.join(self.tmp_artifacts, slug_name+"."+extension)
+        fig.savefig(fname, dpi=dpi, format=extension, bbox_inches="tight", **kwargs)
+
+        self.add_artifact(fname, name=name, step=step, wait_response=wait_response)
 
     @write_method
     @action_method
@@ -175,7 +213,7 @@ class Run():
     @write_method
     @action_method        
     def add_mlmodel(self, source_path: str, name: str, version: str = None, description: str = None,
-                push_dir: bool = False):
+                push_dir: bool = False, resume_upload: bool = False):
         """Add a mlmodel.
 
         source_path: Path to the directory/file of the mlmodel
@@ -185,6 +223,7 @@ class Run():
             model with this name (e.g. 1.3.3 -> 1.4.0)
         description: Short description.
         push_dir: Must be set to True if the source_path is a directory
+        resume_upload: Use resume_upload to resume a failed upload.
         """
         mlmodel = ops_upload_mlmodel(source_path=source_path, 
             mlmodel_name=name,
@@ -192,7 +231,8 @@ class Run():
              project_path=self._project_path,
              version=version,
              short_description=description,
-             push_dir=push_dir)
+             push_dir=push_dir,
+             resume_upload=resume_upload)
         if mlmodel is not None:
             self.add_mlmodel_usage(mlmodel.get('name'), version=mlmodel.get('version'))
 
@@ -529,8 +569,8 @@ class Run():
             logger.error(f"A logger named {logger_name} is returned but the logs aren't saved because you are in a read-only mode.")
             return logging.getLogger(logger_name)
         
-        if (logger_name is None or logger_name=="pyhectiqlab")and level<10:
-            logger.error(f"Cannot assign a level {level} (<10) on root logger. Use a `logger_name` to specify a different stream. Level is switch to 10.")
+        if (logger_name is None or logger_name=="pyhectiqlab") and level<10:
+            logger.error(f"Cannot assign a level {level} (<10) on root logger. Use a `logger_name` to specify a different stream. Level is switched back to 10.")
             level = 10
 
         # Start recording
